# frozen_string_literal: true
#
# Author:: Stuart Preston (<stuart@chef.io>)
# Copyright:: Copyright (c) Chef Software Inc.
# License:: Apache License, Version 2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

Ohai.plugin :SystemEnclosure do
  provides "system_enclosure"
  depends "dmi"

  collect_data(:windows) do
    system_enclosure Mash.new
    system_enclosure[:manufacturer] = get_attribute(:dmi, :chassis, :manufacturer)
    system_enclosure[:serialnumber] = get_attribute(:dmi, :chassis, :serial_number)
  end
end
